@@ -29,11 +29,11 @@ my $list_req = $db->prepare(
 	    order by _categorykeys.value
 	    });
 $list_req->bind_columns(\($category));
+$list_req->execute;
 
 my $list_cat_req = $db->prepare(
 	q{select min(_paths.fullpkgpath),
-		fullpkgname,
-		comment
+		fullpkgname
 	    from _paths
 		join _Ports on _paths.id=_Ports.fullpkgpath 
 		    and _paths.id=_paths.canonical
@@ -43,8 +43,8 @@ my $list_cat_req = $db->prepare(
 		group by fullpkgname
 		order by fullpkgname
 	    });
-my ($fullpkgpath, $fullpkgname, $comment);
-$list_cat_req->bind_columns(\($fullpkgpath, $fullpkgname, $comment));
+my ($fullpkgpath, $fullpkgname);
+$list_cat_req->bind_columns(\($fullpkgpath, $fullpkgname));
 
 my $info_req = $db->prepare(
 	q{select
@@ -65,7 +65,7 @@ my $info_req = $db->prepare(
 		    on _ports.permit_package=permit.keyref
 		join _email on _ports.maintainer=_email.keyref
 	    where _paths.fullpkgpath=?});
-my ($id, $path, $simplepath, $homepage, $descr, $permit, $maintainer);
+my ($id, $path, $simplepath, $comment, $homepage, $descr, $permit, $maintainer);
 $info_req->bind_columns(\($id, $path,  $simplepath, $comment, $homepage, $descr, $fullpkgname, $permit, $maintainer));
 
 my $dep_req = $db->prepare(
@@ -168,53 +168,7 @@ my $canonical_req = $db->prepare(
 my $canonical;
 $canonical_req->bind_columns(\$canonical);
 	    
-my $full_list_req = $db->prepare(
-	q{select min(_paths.fullpkgpath),
-		fullpkgname,
-		comment
-	    from _paths
-		join _Ports on _paths.id=_Ports.fullpkgpath 
-		    and _paths.id=_paths.canonical
-		group by fullpkgname
-		order by fullpkgname
-	});
-$full_list_req->bind_columns(\($fullpkgpath, $fullpkgname, $comment));
-
-my ($version, $creation_date);
-
-my $meta_req = $db->prepare(
-	q{select SchemaVersion, CreationDate from meta});
-$meta_req->bind_columns(\$version, \$creation_date);
-$meta_req->execute;
-while ($meta_req->fetch) {
-}
-
-sub run_locate
-{
-	my ($param, $e, $sub) = @_;
-	if (open(my $fh, "-|", config->{pkglocate}, '--', $param)) {
-		while(<$fh>) {
-			&$sub($_);
-		}
-		if (!close($fh)) {
-			$e->{error} = "running pkglocate $param failed: $! $?";
-		}
-	} else {
-		$e->{error} = "problem creating pipe to pkglocate";
-	}
-}
-
-sub create_hash
-{
-	return {
-	    version => $version,
-	    creation_date => $creation_date,
-	    @_
-	};
-}
-
-my $e = create_hash();
-$list_req->execute;
+my $e;
 while ($list_req->fetch) {
 	push(@{$e->{categories}}, {
 		name => $category,
@@ -231,12 +185,11 @@ sub category
 {
 	my ($class, $cat) = @_;
 	$list_cat_req->execute($cat);
-	my $e = create_hash( name => $cat );
+	my $e = { name => $cat };
 	while ($list_cat_req->fetch) {
 		push(@{$e->{category}}, {
 			name => $fullpkgname,
-			url => "/path/$fullpkgpath",
-			comment => $comment
+			url => "/path/$fullpkgpath"
 		});
 	}
 	return $e;
@@ -253,13 +206,13 @@ sub pkgpath
 	}
 	# zap the email part
 	$maintainer =~ s/\s+\<.*?\>//g;
-	my $e = create_hash( path => $path,
+	my $e = { path => $path,
 		simplepath => $simplepath,
 		comment => $comment,
 		homepage => $homepage,
 		maintainer => $maintainer,
 		descr => $descr,
-		fullpkgname => $fullpkgname );
+		fullpkgname => $fullpkgname };
 	unless ($permit =~ /yes/i) {
 		$e->{permit} = $permit;
 	}
@@ -279,13 +232,14 @@ sub pkgpath
 			url => "/path/$revpath"
 		    });
 	}
-	run_locate(":$path:", $e,
-	    sub {
-		    $_ = shift;
-		    if (m/^\Q$fullpkgname\E:\Q$path\E:(.*)/) {
-			    push(@{$e->{files}}, $1);
-		    }
-	    });
+	if (open(my $fh, "-|", config->{pkglocate}, ":$path:")) {
+		while (<$fh>) {
+			if (m/^\Q$fullpkgname\E:\Q$path\E:(.*)/) {
+				push(@{$e->{files}}, $1);
+			}
+		}
+		close $fh;
+	}
 
 	$broken_req->execute($id);
 	while ($broken_req->fetch) {
@@ -338,40 +292,24 @@ sub canonical
 	}
 }
 
-sub full_list
-{
-	$full_list_req->execute;
-	my $e = {};
-	while ($full_list_req->fetch) {
-		push(@{$e->{packages}}, {
-		    name => $fullpkgname,
-		    url => "/path/".$fullpkgpath,
-		    comment => $comment
-		     });
-	}
-	return $e;
-}
-
 sub search
 {
 	my ($class, $search) = @_;
 	my $s = "";
 	my @params = ();
 	my @where = ();
-	my $e = create_hash();
 
 	if ($search->{file}) {
 		my %h;
-		run_locate($search->{file}, $e,
-		    sub {
-			    $_ = shift;
-			    return unless m/^.*?\:(.*?)\:(.*)/;
-			    my ($pkgpath, $filepath) = ($1, $2);
-			    return unless $filepath =~ m/\Q$search->{file}\E/;
-			    $h{$pkgpath} = 1;
-		    });
-		push(@where, "_paths.fullpkgpath in (".
-		    join(', ', map {$db->quote($_)} keys %h).")");
+		if (open(my $fh, "-|", config->{pkglocate}, $search->{file})) {
+			while (<$fh>) {
+				if (m/^.*?\:(.*?)\:/) {
+					$h{$1} = 1;
+				}
+			}
+			close $fh;
+			push(@where, "_paths.fullpkgpath in (".join(', ', map {$db->quote($_)} keys %h).")");
+		}
 	}
 
 	if ($search->{descr}) {
@@ -406,20 +344,20 @@ sub search
 		$s.= " where ".join(" and ", @where);
 	}
 	$s = qq{select
-		_paths.fullpkgpath, fullpkgname, comment
+		_paths.fullpkgpath, fullpkgname
 	    from _paths
-		join _Ports on _paths.canonical=_Ports.fullpkgpath
+		join _Ports on _paths.id=_Ports.fullpkgpath
 		$s
 		order by fullpkgname
 		};
 	my $req = $db->prepare($s);
-	$req->bind_columns(\($fullpkgpath, $fullpkgname, $comment));
+	$req->bind_columns(\($fullpkgpath, $fullpkgname));
 	$req->execute(@params);
+	my $e = {};
 	while ($req->fetch) {
 		push(@{$e->{result}}, {
 			name => $fullpkgname,
-			url => "/path/$fullpkgpath",
-			comment => $comment
+			url => "/path/$fullpkgpath"
 		});
 	}
 	return $e;
